#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = require("path");
const yargs_1 = tslib_1.__importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const runner_1 = tslib_1.__importDefault(require("./runner"));
const cli = (0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
    .option('token', {
    alias: 't',
    type: 'string',
    description: 'Your GitHub auth token',
})
    .option('preset', {
    alias: 'p',
    default: 'angular',
    type: 'string',
    description: `Name of the preset you want to use. Must be one of the following: ` +
        `angular, atom, codemirror, ember, eslint, express, jquery, jscs or jshint`,
})
    .option('pkg', {
    alias: 'k',
    type: 'string',
    description: `A filepath of where your package.json is located. Default is the closest package.json from cwd`,
})
    .option('releases', {
    alias: 'r',
    default: 1,
    type: 'number',
    description: `How many releases to be generated from the latest. ` +
        `If 0, the whole changelog will be regenerated and the output file will be overwritten`,
})
    .option('prefix', {
    alias: 'f',
    default: '',
    type: 'string',
    description: `Release name prefix`,
})
    .option('config', {
    alias: 'n',
    type: 'string',
    description: 'A filepath of your config script',
})
    .option('context', {
    alias: 'c',
    type: 'string',
    description: 'A filepath of a javascript that is used to define template variables',
})
    .option('draft', {
    alias: 'd',
    default: false,
    type: 'boolean',
    description: 'Publish a draft release',
})
    .option('verbose', {
    alias: 'v',
    default: false,
    type: 'boolean',
    description: 'Verbose output. Use this for debugging',
})
    .usage('Usage: cc-github-releaser [options]')
    .parse();
if (cli instanceof Promise) {
    throw new TypeError('Can not process async cli object');
}
let config = {};
let context;
let gitRawCommitsOpts;
let parserOpts;
let writerOpts;
try {
    if (cli.context) {
        context = require((0, path_1.resolve)(process.cwd(), cli.context));
    }
    if (cli.config) {
        config = require((0, path_1.resolve)(process.cwd(), cli.config));
    }
    if (config.gitRawCommitsOpts) {
        gitRawCommitsOpts = config.gitRawCommitsOpts;
    }
    if (config.parserOpts) {
        parserOpts = config.parserOpts;
    }
    if (config.writerOpts) {
        writerOpts = config.writerOpts;
    }
}
catch (error) {
    console.error('Failed to get file:', error);
    process.exit(1);
}
const changelogOpts = {
    preset: cli.preset,
    pkg: { path: cli.pkg },
    releaseCount: cli.releases,
    releasePrefix: cli.prefix,
    draft: cli.draft,
};
(0, runner_1.default)({
    token: cli.token ||
        process.env['GITHUB_TOKEN'] ||
        process.env['GH_TOKEN'] ||
        process.env['CONVENTIONAL_GITHUB_RELEASER_TOKEN'] ||
        '',
    changelogOpts,
    context,
    gitRawCommitsOpts,
    parserOpts,
    writerOpts,
    userCb: (err, data) => {
        if (err) {
            console.error(err.toString());
            process.exit(1);
        }
        if (cli.verbose) {
            console.log(data);
        }
    },
});
