"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const got_1 = tslib_1.__importDefault(require("got"));
const create = () => got_1.default.extend({
    prefixUrl: process.env['GITHUB_ENDPOINT'] || 'https://api.github.com',
    headers: {
        accept: 'application/vnd.github.v3+json',
        'user-agent': 'cc-github-releaser',
    },
    responseType: 'json',
    context: { token: process.env['GITHUB_TOKEN'] },
    handlers: [
        (options, next) => {
            var _a, _b;
            if (((_a = options.context) === null || _a === void 0 ? void 0 : _a.token) && !options.headers.authorization) {
                options.headers.authorization = `token ${options.context.token}`;
            }
            if ((_b = options.context) === null || _b === void 0 ? void 0 : _b.accept) {
                options.headers.accept = options.context.accept;
            }
            options.json = options.body;
            delete options.body;
            if (options.isStream) {
                return next(options);
            }
            return (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                try {
                    return (yield next(options));
                }
                catch (error) {
                    const { response } = error;
                    if (response) {
                        error.statusCode = response.statusCode;
                    }
                    if (response === null || response === void 0 ? void 0 : response.body) {
                        error.body = response.body;
                    }
                    if (response === null || response === void 0 ? void 0 : response.body) {
                        error.name = 'GitHubError';
                        error.message = `${response.body.message} (${response.statusCode})`;
                    }
                    throw error;
                }
            }))();
        },
    ],
});
exports.default = create();
