"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const conventional_changelog_1 = tslib_1.__importDefault(require("conventional-changelog"));
const git_semver_tags_1 = tslib_1.__importDefault(require("git-semver-tags"));
const semver_1 = require("semver");
const stream_1 = require("stream");
const got_wrapper_1 = tslib_1.__importDefault(require("./got-wrapper"));
const transformer_1 = require("./transformer");
function ccGithubReleaser({ token, changelogOpts, context, gitRawCommitsOpts, parserOpts, writerOpts, userCb, }) {
    if (!token) {
        throw new Error('Expected an auth token');
    }
    if (!userCb) {
        throw new Error('Expected a callback');
    }
    const _changelogOpts = Object.assign({}, { transform: transformer_1.transformer, releaseCount: 1 }, changelogOpts || {}), _context = context || {}, _parserOpts = parserOpts || {}, _writerOpts = Object.assign({}, writerOpts || {}, {
        includeDetails: true,
        headerPartial: (writerOpts === null || writerOpts === void 0 ? void 0 : writerOpts.headerPartial) || '',
    });
    let _gitRawCommitsOpts = gitRawCommitsOpts || {};
    const requests = [];
    (0, git_semver_tags_1.default)((err, tags) => (err ? userCb(err) : generateChangelogs(tags)));
    const generateChangelogs = (tags) => {
        if (!(tags === null || tags === void 0 ? void 0 : tags.length)) {
            setImmediate(userCb, new Error('No semver tags found'));
            return;
        }
        const releaseCount = _changelogOpts.releaseCount;
        if (releaseCount !== 0) {
            _gitRawCommitsOpts = Object.assign({}, { from: tags[releaseCount] }, _gitRawCommitsOpts);
        }
        _gitRawCommitsOpts.to = _gitRawCommitsOpts.to || tags[0];
        (0, conventional_changelog_1.default)(_changelogOpts, _context, _gitRawCommitsOpts, _parserOpts, _writerOpts)
            .on('error', (err) => userCb(err))
            .pipe(new stream_1.Transform({
            transform: createApiRequest,
            flush: executeApiRequests,
            objectMode: true,
            highWaterMark: 16,
        }));
    };
    const createApiRequest = (chunk, enc, cb) => {
        var _a;
        if (!((_a = chunk === null || chunk === void 0 ? void 0 : chunk.keyCommit) === null || _a === void 0 ? void 0 : _a.version)) {
            cb();
            return;
        }
        requests.push((0, got_wrapper_1.default)(`repos/${_context.owner}/${_context.repository}/releases`, {
            method: 'POST',
            context: { token },
            body: {
                tag_name: chunk.keyCommit.version,
                target_commitish: _changelogOpts.targetCommitish,
                name: (_changelogOpts.releasePrefix || '') + (_changelogOpts.name || chunk.keyCommit.version),
                body: chunk.log,
                draft: _changelogOpts.draft || false,
                prerelease: (0, semver_1.parse)(chunk.keyCommit.version).prerelease.length > 0,
            },
        }));
        cb();
    };
    const executeApiRequests = () => Promise.all(requests)
        .then((responses) => userCb(null, responses))
        .catch((error) => userCb(error));
}
exports.default = ccGithubReleaser;
